v3.1.0
======

Switch to native namespace for 'jaraco' package and other refresh.

v3.0.0
======

#6: Copy/paste HTML now fixed by building on fixes in jaraco.windows.

Require Python 3.6 or later.

2.0.1
=====

#4: Fix usage of richxerox for HTML copy operation on macOS.

2.0
===

Switch to `pkgutil namespace technique
<https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages>`_
for the ``jaraco`` namespace.

1.3.4
=====

#3: Fixed paste_html on Windows.

1.3.3
=====

Bump to richxerox 1.0.1 for declared dependency on pyobjc.

Run CI tests on macOS and Windows.

1.3.2
=====

Refresh packaging.

Update dependency declaration on richxerox.

Update dependency on pyperclip and fix usage.

1.3.1
=====

Refresh packaging.

1.3
===

Add support for copy/paste text on Linux via pyperclip.

1.2
===

Added test suite and automated deployments for tagged
commits.

1.1
===

Move hosting to github.

1.0
===

Initial implementation with text and HTML support on Windows
and Mac OS X and image paste support on Windows.
